@@ -1,7 +1,7 @@
 """
 Type annotations for ssm service literal definitions.
 
-[Open documentation](./literals.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals.html)
 
 Usage::
 
@@ -106,6 +106,7 @@ __all__ = (
     "ListDocumentVersionsPaginatorName",
     "ListDocumentsPaginatorName",
     "ListOpsItemEventsPaginatorName",
+    "ListOpsItemRelatedItemsPaginatorName",
     "ListOpsMetadataPaginatorName",
     "ListResourceComplianceSummariesPaginatorName",
     "ListResourceDataSyncPaginatorName",
@@ -121,6 +122,8 @@ __all__ = (
     "OpsItemEventFilterOperator",
     "OpsItemFilterKey",
     "OpsItemFilterOperator",
+    "OpsItemRelatedItemsFilterKey",
+    "OpsItemRelatedItemsFilterOperator",
     "OpsItemStatus",
     "ParameterTier",
     "ParameterType",
@@ -282,6 +285,8 @@ DocumentType = Literal[
     "DeploymentStrategy",
     "Package",
     "Policy",
+    "ProblemAnalysis",
+    "ProblemAnalysisTemplate",
     "Session",
 ]
 ExecutionMode = Literal["Auto", "Interactive"]
@@ -318,6 +323,7 @@ ListComplianceSummariesPaginatorName = Literal["list_compliance_summaries"]
 ListDocumentVersionsPaginatorName = Literal["list_document_versions"]
 ListDocumentsPaginatorName = Literal["list_documents"]
 ListOpsItemEventsPaginatorName = Literal["list_ops_item_events"]
+ListOpsItemRelatedItemsPaginatorName = Literal["list_ops_item_related_items"]
 ListOpsMetadataPaginatorName = Literal["list_ops_metadata"]
 ListResourceComplianceSummariesPaginatorName = Literal["list_resource_compliance_summaries"]
 ListResourceDataSyncPaginatorName = Literal["list_resource_data_sync"]
@@ -382,6 +388,8 @@ OpsItemFilterKey = Literal[
     "Title",
 ]
 OpsItemFilterOperator = Literal["Contains", "Equal", "GreaterThan", "LessThan"]
+OpsItemRelatedItemsFilterKey = Literal["AssociationId", "ResourceType", "ResourceUri"]
+OpsItemRelatedItemsFilterOperator = Literal["Equal"]
 OpsItemStatus = Literal[
     "Approved",
     "Cancelled",
