@@ -62,6 +62,7 @@ from mypy_boto3_ssm.literals import (
     OpsItemDataType,
     OpsItemFilterKey,
     OpsItemFilterOperator,
+    OpsItemRelatedItemsFilterKey,
     OpsItemStatus,
     ParametersFilterKey,
     ParameterTier,
@@ -95,6 +96,7 @@ else:
 __all__ = (
     "AccountSharingInfoTypeDef",
     "ActivationTypeDef",
+    "AssociateOpsItemRelatedItemResponseTypeDef",
     "AssociationDescriptionTypeDef",
     "AssociationExecutionFilterTypeDef",
     "AssociationExecutionTargetTypeDef",
@@ -245,6 +247,7 @@ __all__ = (
     "ListDocumentsResultTypeDef",
     "ListInventoryEntriesResultTypeDef",
     "ListOpsItemEventsResponseTypeDef",
+    "ListOpsItemRelatedItemsResponseTypeDef",
     "ListOpsMetadataResultTypeDef",
     "ListResourceComplianceSummariesResultTypeDef",
     "ListResourceDataSyncResultTypeDef",
@@ -277,6 +280,8 @@ __all__ = (
     "OpsItemFilterTypeDef",
     "OpsItemIdentityTypeDef",
     "OpsItemNotificationTypeDef",
+    "OpsItemRelatedItemSummaryTypeDef",
+    "OpsItemRelatedItemsFilterTypeDef",
     "OpsItemSummaryTypeDef",
     "OpsItemTypeDef",
     "OpsMetadataFilterTypeDef",
@@ -373,6 +378,10 @@ class ActivationTypeDef(TypedDict, total=False):
     Tags: List["TagTypeDef"]
 
 
+class AssociateOpsItemRelatedItemResponseTypeDef(TypedDict, total=False):
+    AssociationId: str
+
+
 class AssociationDescriptionTypeDef(TypedDict, total=False):
     Name: str
     InstanceId: str
@@ -992,6 +1001,7 @@ class DocumentDescriptionTypeDef(TypedDict, total=False):
     Hash: str
     HashType: DocumentHashType
     Name: str
+    DisplayName: str
     VersionName: str
     Owner: str
     CreatedDate: datetime
@@ -1024,6 +1034,8 @@ class DocumentFilterTypeDef(TypedDict):
 
 class DocumentIdentifierTypeDef(TypedDict, total=False):
     Name: str
+    CreatedDate: datetime
+    DisplayName: str
     Owner: str
     VersionName: str
     PlatformTypes: List[PlatformType]
@@ -1085,6 +1097,7 @@ class DocumentReviewsTypeDef(_RequiredDocumentReviewsTypeDef, total=False):
 
 class DocumentVersionInfoTypeDef(TypedDict, total=False):
     Name: str
+    DisplayName: str
     DocumentVersion: str
     VersionName: str
     CreatedDate: datetime
@@ -1161,6 +1174,8 @@ class GetDeployablePatchSnapshotForInstanceResultTypeDef(TypedDict, total=False)
 
 class GetDocumentResultTypeDef(TypedDict, total=False):
     Name: str
+    CreatedDate: datetime
+    DisplayName: str
     VersionName: str
     DocumentVersion: str
     Status: DocumentStatus
@@ -1581,6 +1596,11 @@ class ListOpsItemEventsResponseTypeDef(TypedDict, total=False):
     Summaries: List["OpsItemEventSummaryTypeDef"]
 
 
+class ListOpsItemRelatedItemsResponseTypeDef(TypedDict, total=False):
+    NextToken: str
+    Summaries: List["OpsItemRelatedItemSummaryTypeDef"]
+
+
 class ListOpsMetadataResultTypeDef(TypedDict, total=False):
     OpsMetadataList: List["OpsMetadataTypeDef"]
     NextToken: str
@@ -1822,6 +1842,24 @@ class OpsItemNotificationTypeDef(TypedDict, total=False):
     Arn: str
 
 
+class OpsItemRelatedItemSummaryTypeDef(TypedDict, total=False):
+    OpsItemId: str
+    AssociationId: str
+    ResourceType: str
+    AssociationType: str
+    ResourceUri: str
+    CreatedBy: "OpsItemIdentityTypeDef"
+    CreatedTime: datetime
+    LastModifiedBy: "OpsItemIdentityTypeDef"
+    LastModifiedTime: datetime
+
+
+class OpsItemRelatedItemsFilterTypeDef(TypedDict):
+    Key: OpsItemRelatedItemsFilterKey
+    Values: List[str]
+    Operator: Literal["Equal"]
+
+
 class OpsItemSummaryTypeDef(TypedDict, total=False):
     CreatedBy: str
     CreatedTime: datetime
